#
# spec file for package findutils
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           findutils
Url:            http://www.gnu.org/software/findutils/
Version:        4.6.0
Release:        0
Summary:        The GNU versions of find utilities (find and xargs)
License:        GPL-3.0-or-later
Group:          Productivity/File utilities

# For upgrading you now just need to increase the version, remove the old
# tarballs, then run osc service localrun download_files, osc addremove,
# osc vc and osc ci and you are done.
Source0:        http://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.gz
#Source1:        https://ftp.gnu.org/gnu/%%{name}/%%{name}-%%{version}.tar.gz.sig
#Source2:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=%%{name}&download=1&file=./%%{name}.keyring

# adds a new option -xautofs to find to not descend into directories on autofs file systems
Patch0:         findutils-4.4.2-xautofs.patch

# Upstream patch, to be removed with version 4.7.0.
Patch100:       sv-bug-48030-find-exec-plus-does-not-pass-all-arguments.patch

# Update gnulib for libio.h removal
Patch101:       gnulib-libio.patch
# Update gnulib for <sys/sysmacros.h> requirement (simplified to avoid configure changes)
Patch102:       sysmacros.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# BuildRequire dejagnu for 'runtest' to execute all tests.
BuildRequires:  dejagnu
%if 0%{?suse_version} > 1100
BuildRequires:  libselinux-devel
%endif
BuildRequires:  makeinfo
Provides:       find = %{version}
Obsoletes:      find < %{version}
Requires(post):  %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
The findutils package contains programs which will help you locate
files on your system.  The find utility searches through a hierarchy
of directories looking for files which match a certain set of criteria
(such as a file name pattern).  The xargs utility builds and executes
command lines from standard input arguments (usually lists of file
names generated by the find command).

You should install findutils because it includes tools that are very
useful for finding things on your system.


%lang_package

%prep
%setup -q
%patch0
%patch100
%patch101 -p1
%patch102 -p1

%build
%if 0%{?qemu_user_space_build}
# this is a workaround for a qemu-user bug, we hit. A qemu patch is being discussed, but for now ...
export DEFAULT_ARG_SIZE="(31u * 1024u)"
%endif
%configure \
  --libexecdir=%{_libdir}/find \
  --localstatedir=/var/lib

make %{?_smp_mflags}

%check
if [ "%{version}" != '4.6.0' ]; then
  echo "ERROR: remove this if-else-fi block from the spec file with findutils version >4.6.0." >&2
  exit 1
else
  # Make the test script added with 'sv-48030*.patch' executable.
  chmod +x find/testsuite/sv-48030-exec-plus-bug.sh
fi
make check \
  || { cat tests/test-suite.log; exit 1; }

%install
make DESTDIR=%{buildroot} install

rm -f %{buildroot}%{_infodir}/find-maint*
%find_lang %{name}
#UsrMerge
mkdir -p %{buildroot}/bin
ln -sf %{_bindir}/find %{buildroot}/bin
#UsrMerge

rm %{buildroot}%{_bindir}/locate
rm %{buildroot}%{_bindir}/updatedb
rm -r %{buildroot}%{_libdir}/find
rm %{buildroot}%{_mandir}/man1/locate.1*
rm %{buildroot}%{_mandir}/man1/updatedb.1*
rm %{buildroot}%{_mandir}/man5/locatedb.5*

%post
%install_info --info-dir=%{_infodir} %{_infodir}/find.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/find.info.gz

%files
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS NEWS README THANKS TODO
#UsrMerge
/bin/find
#UsrMerge
%{_bindir}/find
%{_bindir}/xargs
%doc %{_infodir}/find.info*.gz
%doc %{_mandir}/man1/find.1.gz
%doc %{_mandir}/man1/xargs.1.gz

%files lang -f %{name}.lang
%defattr(-,root,root,-)

%changelog
